# oddsmaker
Package that implements common ratings systems that are applicable to a wide range of sports and data types.

## Overview

The problem that this package sets out to address is that a lot of publicly available time series prediction methods are inadequate for predicting sports because of the pairwise nature of many sporting competitions. In other words, something like an ARIMA model would have some predictive power, however it is not by default capable of taking into account opponent quality. This package implements and extends many public rating systems that both adjust for opponent and (mostly) have time components as well.  

The goal of this package is to be able to quickly test and apply many of these rating options to data of a generic structure. For more explanation, check out the Quick Start and Documentation. 

## Implemented Algorithms (v 0.1.0)

#### State Space  
1. Classic Elo
2. Elo with Uncertainty

#### Linear
1. Ridge
2. KenPom
3. Massey

#### Graph
1. Pagerank

Many more (hopefully) coming!

## Installation

## Quick Start

## Documentation and Other Links




